@@ -3,7 +3,7 @@ function(rmas, bootsp=1000){
   x<-rmas # TODO: change x for rmas in all function
    if(class(x)[1]!="rmas") stop("explosion requires an rmas object
                               (i.e. a trajectory simulation from projectn)")
-   if(length(names(x))>0){ # bifurcacin provisional para separar rmas de projectn y de projectn2
+   if(length(names(x))>0){ # bifurcacion provisional para separar rmas de projectn y de projectn2
          x<- x$vn
   }
    
